==> react-bootstrap-range-slider-1.2.1.tgz: react-bootstrap-range-slider/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-range-slider`

# Summary
This package contains type definitions for react-bootstrap-range-slider (https://github.com/jaywilz/react-bootstrap-range-slider#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-range-slider.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-range-slider/index.d.ts)
````ts
// Type definitions for react-bootstrap-range-slider 1.2
// Project: https://github.com/jaywilz/react-bootstrap-range-slider#readme
// Definitions by: Isaac Moore <https://github.com/rmsy>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import {
    ChangeEvent,
    CSSProperties,
    DetailedHTMLProps,
    ForwardRefExoticComponent,
    HTMLAttributes,
    MouseEvent,
    PropsWithoutRef,
    ReactNode,
    RefAttributes,
    RefObject,
} from 'react';

export interface RangeSliderProps {
    value?: number | undefined;
    onChange?: ((event: ChangeEvent<HTMLInputElement>, value: number) => void) | undefined;
    onAfterChange?: ((event: MouseEvent<HTMLInputElement>, value: number) => void) | undefined;
    min?: number | undefined;
    max?: number | undefined;
    step?: number | undefined;
    disabled?: boolean | undefined;
    size?: 'sm' | 'lg' | undefined;
    variant?: 'primary' | 'secondary' | 'success' | 'danger' | 'warning' | 'info' | 'dark' | 'light' | undefined;
    inputProps?: DetailedHTMLProps<HTMLAttributes<HTMLInputElement>, HTMLInputElement> | undefined;
    tooltip?: 'auto' | 'on' | 'off' | undefined;
    tooltipPlacement?: 'top' | 'bottom' | undefined;
    tooltipLabel?: ((value: number) => ReactNode) | undefined;
    tooltipStyle?: CSSProperties | undefined;
    tooltipProps?: DetailedHTMLProps<HTMLAttributes<HTMLDivElement>, HTMLDivElement> | undefined;
    className?: string | undefined;
    ref?: ((instance: HTMLInputElement | null) => void) | RefObject<HTMLInputElement> | null | undefined;
    bsPrefix?: string | undefined;
}

export const RangeSlider: ForwardRefExoticComponent<
    PropsWithoutRef<RangeSliderProps> & RefAttributes<HTMLInputElement>
>;

export default RangeSlider;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 20:20:27 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)
 * Global values: none

# Credits
These definitions were written by [Isaac Moore](https://github.com/rmsy).

==> react-bootstrap-range-slider-1.2.2.tgz: react-bootstrap-range-slider/README.md <==
# Installation
> `npm install --save @types/react-bootstrap-range-slider`

# Summary
This package contains type definitions for react-bootstrap-range-slider (https://github.com/jaywilz/react-bootstrap-range-slider#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-range-slider.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/react-bootstrap-range-slider/index.d.ts)
````ts
// Type definitions for react-bootstrap-range-slider 1.2
// Project: https://github.com/jaywilz/react-bootstrap-range-slider#readme
// Definitions by: Isaac Moore <https://github.com/rmsy>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

import {
    ChangeEvent,
    CSSProperties,
    DetailedHTMLProps,
    ForwardRefExoticComponent,
    HTMLAttributes,
    MouseEvent,
    PropsWithoutRef,
    ReactNode,
    RefAttributes,
    RefObject,
} from "react";

export interface RangeSliderProps {
    value?: number | undefined;
    onChange?: ((event: ChangeEvent<HTMLInputElement>, value: number) => void) | undefined;
    onAfterChange?: ((event: MouseEvent<HTMLInputElement>, value: number) => void) | undefined;
    min?: number | undefined;
    max?: number | undefined;
    step?: number | undefined;
    disabled?: boolean | undefined;
    size?: "sm" | "lg" | undefined;
    variant?: "primary" | "secondary" | "success" | "danger" | "warning" | "info" | "dark" | "light" | undefined;
    inputProps?: DetailedHTMLProps<HTMLAttributes<HTMLInputElement>, HTMLInputElement> | undefined;
    tooltip?: "auto" | "on" | "off" | undefined;
    tooltipPlacement?: "top" | "bottom" | undefined;
    tooltipLabel?: ((value: number) => ReactNode) | undefined;
    tooltipStyle?: CSSProperties | undefined;
    tooltipProps?: DetailedHTMLProps<HTMLAttributes<HTMLDivElement>, HTMLDivElement> | undefined;
    className?: string | undefined;
    ref?: ((instance: HTMLInputElement | null) => void) | RefObject<HTMLInputElement> | null | undefined;
    bsPrefix?: string | undefined;
}

export const RangeSlider: ForwardRefExoticComponent<
    PropsWithoutRef<RangeSliderProps> & RefAttributes<HTMLInputElement>
>;

export default RangeSlider;

````

### Additional Details
 * Last updated: Wed, 27 Sep 2023 07:12:04 GMT
 * Dependencies: [@types/react](https://npmjs.com/package/@types/react)
 * Global values: none

# Credits
These definitions were written by [Isaac Moore](https://github.com/rmsy).
